@@ -118,11 +118,14 @@ const struct mode_info_t mode_info[NUM_MODES] = {
 	{ MODE_QPSK500, &qpsk500_modem, "QPSK500", "QPSK-500", "QPSK500", "QPSK500", "Q500",  ARQ_IO | KISS_IO  },
 
 	{ MODE_8PSK125, &_8psk125_modem, "8PSK125", "8PSK-125", "8PSK125", "8PSK125", "8PSK125", ARQ_IO | KISS_IO },
+	{ MODE_8PSK125F, &_8psk125f_modem, "8PSK125F", "8PSK-125F", "8PSK125F", "8PSK125F", "8PSK125F", ARQ_IO | KISS_IO },
 	{ MODE_8PSK250, &_8psk250_modem, "8PSK250", "8PSK-250", "8PSK250", "8PSK250", "8PSK250", ARQ_IO | KISS_IO },
+	{ MODE_8PSK250F, &_8psk250f_modem, "8PSK250F", "8PSK-250F", "8PSK250F", "8PSK250F", "8PSK250F", ARQ_IO | KISS_IO },
 	{ MODE_8PSK500, &_8psk500_modem, "8PSK500", "8PSK-500", "8PSK500", "8PSK500", "8PSK500", ARQ_IO | KISS_IO },
+	{ MODE_8PSK500F, &_8psk500f_modem, "8PSK500F", "8PSK-500F", "8PSK500F", "8PSK500F", "8PSK500F", ARQ_IO | KISS_IO },
 	{ MODE_8PSK1000, &_8psk1000_modem, "8PSK1000", "8PSK-1000", "8PSK1000", "8PSK1000", "8PSK1000", ARQ_IO | KISS_IO },
-	{ MODE_8PSK1200, &_8psk1200_modem, "8PSK1200", "8PSK-1200", "8PSK1200", "8PSK1200", "8PSK1200", ARQ_IO | KISS_IO },
-	{ MODE_8PSK1333, &_8psk1333_modem, "8PSK1333", "8PSK-1333", "8PSK1333", "8PSK1333", "8PSK1333", ARQ_IO | KISS_IO },
+	{ MODE_8PSK1000F, &_8psk1000f_modem, "8PSK1000F", "8PSK-1000F", "8PSK1000F", "8PSK1000F", "8PSK1000F", ARQ_IO | KISS_IO },
+	{ MODE_8PSK1200F, &_8psk1200f_modem, "8PSK1200F", "8PSK-1200F", "8PSK1200F", "8PSK1200F", "8PSK1200F", ARQ_IO | KISS_IO },
 
 	{ MODE_OLIVIA, &olivia_modem, "OLIVIA", "OLIVIA", "OLIVIA", "OLIVIA", "OL", DISABLED_IO },
 	{ MODE_OLIVIA_4_250, &olivia_4_250_modem, "Olivia-4-250", "OL 4-250", "OLIV 4/250", "OLIVIA", "OL4/250", ARQ_IO  },
@@ -191,7 +194,10 @@ const struct mode_info_t mode_info[NUM_MODES] = {
 	{ MODE_SSB, &ssb_modem, "SSB", "SSB", "", "SSB", "", DISABLED_IO },
 	{ MODE_WWV, &wwv_modem, "WWV", "WWV", "", "", "", DISABLED_IO },
 	{ MODE_ANALYSIS, &anal_modem, "ANALYSIS", "Freq Analysis", "", "", "", DISABLED_IO },
-	{ MODE_FFTSCAN, &fftscan_modem, "FREQSCAN", "Freq Scan", "", "", "", DISABLED_IO }
+	{ MODE_FFTSCAN, &fftscan_modem, "FREQSCAN", "Freq Scan", "", "", "", DISABLED_IO },
+
+	{ MODE_FSQ, &fsq_modem, "FSQ", "FSQ", "", "", "", DISABLED_IO }
+
 };
 
 std::ostream& operator<<(std::ostream& s, const qrg_mode_t& m)
