@@ -137,13 +137,16 @@ enum {
 	MODE_QPSK_LAST = MODE_QPSK500,
 
 	MODE_8PSK125,
+	MODE_8PSK125F,
 	MODE_8PSK250,
+	MODE_8PSK250F,
 	MODE_8PSK500,
+	MODE_8PSK500F,
 	MODE_8PSK1000,
-	MODE_8PSK1200,
-	MODE_8PSK1333,
+	MODE_8PSK1000F,
+	MODE_8PSK1200F,
 	MODE_8PSK_FIRST = MODE_8PSK125,
-	MODE_8PSK_LAST = MODE_8PSK1333,
+	MODE_8PSK_LAST = MODE_8PSK1200F,
 
 	MODE_OLIVIA,
 	MODE_OLIVIA_4_250,
@@ -223,6 +226,8 @@ enum {
 	MODE_ANALYSIS,
 	MODE_FFTSCAN,
 
+	MODE_FSQ,
+
 	NUM_MODES,
 	NUM_RXTX_MODES = NUM_MODES - 2
 };
