@@ -141,10 +141,19 @@ public:
 	void		ModulateXmtr(double *, int);
 	void		ModulateStereo(double *, double *, int, bool sample_flag = true);
 
+	void		ModulateVideo(double *, int);
+	void		ModulateVideoStereo(double *, double *, int, bool sample_flag = true);
+
 	void		videoText();
 	void		pretone();
 
-	virtual void		send_image(std::string) {}
+	virtual void		send_color_image(std::string) {}
+	virtual void		send_Grey_image(std::string) {}
+
+	virtual void		fsq_send_image(){}
+	virtual const char *fsq_mycall() {return "";}
+	virtual bool		fsq_squelch_open() {return false;}
+	virtual void		fsq_transmit(void *) {}
 
 	void		set_stopflag(bool b) { stopflag = b;};
 	bool		get_stopflag() const { return stopflag; };
@@ -240,6 +249,9 @@ public:
 	virtual void stop_csv() {}
 	virtual int is_csv() { return true;}
 	virtual double track_freq() { return 0;}
+
+// fsq mode
+	virtual void send_ack(std::string relay) {};
 };
 
 extern modem *null_modem;
@@ -302,6 +314,13 @@ extern modem *_8psk1000_modem;
 extern modem *_8psk1200_modem;
 extern modem *_8psk1333_modem;
 
+extern modem *_8psk125f_modem;
+extern modem *_8psk250f_modem;
+extern modem *_8psk500f_modem;
+extern modem *_8psk1000f_modem;
+extern modem *_8psk1200f_modem;
+extern modem *_8psk1333f_modem;
+
 extern modem *psk125r_modem;
 extern modem *psk250r_modem;
 extern modem *psk500r_modem;
@@ -388,5 +407,6 @@ extern modem *anal_modem;
 extern modem *fftscan_modem;
 extern modem *ssb_modem;
 
+extern modem *fsq_modem;
 
 #endif
