@@ -70,16 +70,16 @@ public:
 	void	clear();
 	void	image(Fl_Image *img) {Fl_Widget::image(img);}
 	void	resize(int, int, int, int);
-	void    resize_height(int new_height, bool clear_img);
-	void    shift_horizontal_center(int hShift);
-	void    stretch(double the_ratio);
-	int	save_png(const char * filename, bool monochrome = false, const char * extra_comments = NULL);
-	void    set_zoom(int the_zoom);
-	void    set_binary(bool bin_mode) { binary = bin_mode ;}
-	int     pix_width(void) const {
+	void	resize_height(int new_height, bool clear_img);
+	void	shift_horizontal_center(int hShift);
+	void	stretch(double the_ratio);
+	int		save_png(const char * filename, bool monochrome = false, const char * extra_comments = NULL);
+	void	set_zoom(int the_zoom);
+	void	set_binary(bool bin_mode) { binary = bin_mode ;}
+	int		pix_width(void) const {
 		return width ;
 	}
-	int     pix_height(void) const {
+	int	 pix_height(void) const {
 		return height ;
 	}
 	const unsigned char * buffer(void) const {
@@ -93,6 +93,7 @@ public:
 
 private:
 	bool restore( int row, int margin );
+	bool slantcorr;
 public:
 	void dilatation( int row );
 	void erosion( int row );
@@ -102,6 +103,10 @@ public:
 	unsigned char get_binary_threshold() const {
 		return binary_threshold ;
 	}
+	void slant(int dir);
+	void rotate();
+	void shift_center(int dir);
+	void noslant() {slantcorr = false;}
 };
 
 class picbox : public Fl_Box
