@@ -39,11 +39,20 @@ int pthread_cond_timedwait_rel(pthread_cond_t* cond, pthread_mutex_t* mutex, dou
 
 enum {
 	INVALID_TID = -1,
-	TRX_TID, QRZ_TID, RIGCTL_TID, NORIGCTL_TID, EQSL_TID, ADIF_RW_TID,
+	TRX_TID,
+	QRZ_TID,
+	RIGCTL_TID,
+	NORIGCTL_TID,
+	EQSL_TID,
+	ADIF_RW_TID,
 	XMLRPC_TID,
-	ARQ_TID, ARQSOCKET_TID,
+	ARQ_TID,
+	ARQSOCKET_TID,
+	KISS_TID,
+	KISSSOCKET_TID,
 	FLMAIN_TID,
-	NUM_THREADS, NUM_QRUNNER_THREADS = NUM_THREADS - 1
+	NUM_THREADS,
+	NUM_QRUNNER_THREADS = NUM_THREADS - 1
 };
 
 #ifdef __linux__
