@@ -236,14 +236,51 @@ void start_process(string executable)
 	}
 }
 
+void toggle_io_port_selection(int io_mode)
+{
+	switch(io_mode) {
+		case ARQ_IO:
+			btnEnable_kiss->do_callback();
+			btnEnable_arq->do_callback();
+			progdefaults.changed = false;
+			break;
+
+		case KISS_IO:
+			btnEnable_arq->do_callback();
+			btnEnable_kiss->do_callback();
+			progdefaults.changed = false;
+			break;
+
+		default:
+			LOG_INFO("Unknown data io mode");
+	}
+}
+
 static void auto_start()
 {
+	bool run_flamp = false;
+
+	// Make sure we are in ARQ_IO mode if executing FLAMP
+	if (!progdefaults.auto_flamp_pathname.empty() &&
+		 progdefaults.flamp_auto_enable) {
+		 toggle_io_port_selection(ARQ_IO);
+		 run_flamp = true;
+	}
+
+	// A general wait to ensure FLDIGI initialization of
+	// io ports. 1/4 to 3/4 second delay.
+	int nloops = 0;
+	while(nloops++ < 3) {
+		MilliSleep(250);
+		if(arq_state() && data_io_enabled == ARQ_IO)
+			break; // Exit early if verified.
+	}
+
 	if (!progdefaults.auto_flrig_pathname.empty() &&
 		 progdefaults.flrig_auto_enable)
 		start_process(progdefaults.auto_flrig_pathname);
 
-	if (!progdefaults.auto_flamp_pathname.empty() &&
-		 progdefaults.flamp_auto_enable)
+	if (run_flamp)
 		start_process(progdefaults.auto_flamp_pathname);
 
 	if (!progdefaults.auto_fllog_pathname.empty() &&
@@ -267,24 +304,17 @@ static void auto_start()
 		start_process(progdefaults.auto_prog3_pathname);
 }
 
-void toggle_io_port_selection(int io_mode)
+// reset those default values that have been overriden by a command line parameter
+void check_overrides()
 {
-	switch(io_mode) {
-		case ARQ_IO:
-			btnEnable_kiss->do_callback();
-			btnEnable_arq->do_callback();
-			progdefaults.changed = false;
-			break;
-
-		case KISS_IO:
-			btnEnable_arq->do_callback();
-			btnEnable_kiss->do_callback();
-			progdefaults.changed = false;
-			break;
-
-		default:
-			LOG_INFO("Unknown data io mode");
-	}
+	if (xmlrpc_address_override_flag) 
+		progdefaults.xmlrpc_address = override_xmlrpc_address;
+	if (xmlrpc_port_override_flag)
+		progdefaults.xmlrpc_port = override_xmlrpc_port;
+	if (arq_address_override_flag)
+		progdefaults.arq_address = override_arq_address;
+	if (arq_port_override_flag)
+		progdefaults.arq_port = override_arq_port;
 }
 
 // these functions are all started after Fl::run() is executing
@@ -300,6 +330,8 @@ void delayed_startup(void *)
 
 	XML_RPC_Server::start(progdefaults.xmlrpc_address.c_str(), progdefaults.xmlrpc_port.c_str());
 
+	FLRIG_start_flrig_thread();
+
 	data_io_enabled = DISABLED_IO;
 	arq_init();
 	kiss_init();
@@ -317,6 +349,7 @@ void delayed_startup(void *)
 
 	if (progdefaults.check_for_updates)
 		cb_mnuCheckUpdate((Fl_Widget *)0, NULL);
+
 }
 
 int main(int argc, char ** argv)
@@ -571,9 +604,10 @@ int main(int argc, char ** argv)
 	LOG_INFO("FLMSG_ICS_tmp_dir: %s", FLMSG_ICS_tmp_dir.c_str());
 
 	bool have_config = progdefaults.readDefaultsXML();
+	check_overrides();
 
 	xmlfname = HomeDir;
-	xmlfname.append("rig.xml");
+	xmlfname.append(DEFAULT_RIGXML_FILENAME);
 
 	checkTLF();
 
@@ -1096,12 +1130,10 @@ int parse_args(int argc, char **argv, int& idx)
 			break;
 
 		case OPT_ARQ_ADDRESS:
-			progdefaults.arq_address = optarg;
 			override_arq_address = optarg;
 			arq_address_override_flag = true;
 			break;
 		case OPT_ARQ_PORT:
-			progdefaults.arq_port = optarg;
 			override_arq_port = optarg;
 			arq_address_override_flag = true;
 			break;
@@ -1160,14 +1192,12 @@ int parse_args(int argc, char **argv, int& idx)
 			break;
 
 		case OPT_CONFIG_XMLRPC_ADDRESS:
-			progdefaults.xmlrpc_address = optarg;
 			override_xmlrpc_address = optarg;
 			xmlrpc_address_override_flag = true;
 			break;
 		case OPT_CONFIG_XMLRPC_PORT:
-			progdefaults.xmlrpc_port = optarg;
 			override_xmlrpc_port = optarg;
-			xmlrpc_address_override_flag = true;
+			xmlrpc_port_override_flag = true;
 			break;
 		case OPT_CONFIG_XMLRPC_ALLOW:
 			progdefaults.xmlrpc_allow = optarg;
