@@ -323,6 +323,7 @@ int cb_qso_opMODE()
 	else
 #endif
 		rigCAT_setmode(qso_opMODE->value());
+	set_flrig_mode(qso_opMODE->value());
 	return 0;
 }
 
@@ -331,6 +332,7 @@ int cb_qso_opBW()
 	if (progdefaults.chkUSERIGCATis)
 //    if (!progdefaults.chkUSEXMLRPCis)
 		rigCAT_setwidth(qso_opBW->value());
+	set_flrig_bw(qso_opBW->index());
 	return 0;
 }
 
@@ -342,6 +344,7 @@ void sendFreq(long int f)
 	else
 #endif
 		rigCAT_setfreq(f);
+	set_flrig_freq(f);
 }
 
 void qso_movFreq(Fl_Widget* w, void *data)
@@ -367,6 +370,20 @@ void qso_movFreq(Fl_Widget* w, void *data)
 	return;
 }
 
+void qso_selectFreq(long int rfcarrier, int carrier)
+{
+	if (rfcarrier > 0) {
+		qsoFreqDisp1->value(rfcarrier);
+		qsoFreqDisp2->value(rfcarrier);
+		qsoFreqDisp3->value(rfcarrier);
+		sendFreq(rfcarrier);
+	}
+
+	if (carrier > 0) {
+		active_modem->set_freq(carrier);
+	}
+}
+
 void qso_selectFreq()
 {
 	int n = qso_opBrowser->value();
@@ -394,6 +411,15 @@ void qso_selectFreq()
 	}
 }
 
+void qso_setFreq(long int f)
+{
+	// transceiver frequency
+	if (f > 0) {
+		qsoFreqDisp->value(f);
+		sendFreq(f);
+	}
+}
+
 void qso_setFreq()
 {
 	int n = qso_opBrowser->value();
@@ -401,10 +427,7 @@ void qso_setFreq()
 
 	n -= 1;
 // transceiver frequency
-	if (freqlist[n].rfcarrier > 0) {
-		qsoFreqDisp->value(freqlist[n].rfcarrier);
-		sendFreq(freqlist[n].rfcarrier);
-	}
+ 	qso_setFreq(freqlist[n].rfcarrier);
 }
 
 void qso_delFreq()
