@@ -102,6 +102,13 @@ modem *_8psk1000_modem = 0;
 modem *_8psk1200_modem = 0;
 modem *_8psk1333_modem = 0;
 
+modem *_8psk125f_modem = 0;
+modem *_8psk250f_modem = 0;
+modem *_8psk500f_modem = 0;
+modem *_8psk1000f_modem = 0;
+modem *_8psk1200f_modem = 0;
+modem *_8psk1333f_modem = 0;
+
 modem *psk125r_modem = 0;
 modem *psk250r_modem = 0;
 modem *psk500r_modem = 0;
@@ -166,6 +173,8 @@ modem *thor50x1_modem = 0;
 modem *thor50x2_modem = 0;
 modem *thor100_modem = 0;
 
+modem *fsq_modem = 0;
+
 modem *dominoex4_modem = 0;
 modem *dominoex5_modem = 0;
 modem *dominoex8_modem = 0;
@@ -436,9 +445,12 @@ void modem::s2nreport(void)
 	pskmail_notify_s2n(s2n_ncount, s2n_avg, s2n_stddev);
 }
 
+bool disable_modem = false;
+
 void modem::ModulateXmtr(double *buffer, int len)
 {
 	if (unlikely(!scard)) return;
+	if (disable_modem) return;
 
 	tx_sample_count += len;
 
@@ -455,11 +467,12 @@ void modem::ModulateXmtr(double *buffer, int len)
 
 	if (withnoise && progdefaults.noise) add_noise(buffer, len);
 
-	double mult = 0.99 * pow(10, progdefaults.txlevel / 20.0);
+	double mult = pow(10, progdefaults.txlevel / 20.0);
+	if (mult > 0.99) mult = 0.99;
 	for (int i = 0; i < len; i++) {
 		buffer[i] *= mult;
-		if (buffer[i] < -1.0) buffer[i] = -1.0;
-		if (buffer[i] >  1.0) buffer[i] = 1.0;
+		if (buffer[i] < -0.99) buffer[i] = -0.99;
+		if (buffer[i] >  0.99) buffer[i] = 0.99;
 	}
 
 	try {
@@ -475,12 +488,54 @@ void modem::ModulateXmtr(double *buffer, int len)
 		}
 		return;
 	}
-
 }
 
 #include <iostream>
 using namespace std;
 void modem::ModulateStereo(double *left, double *right, int len, bool sample_flag)
+{
+	if (unlikely(!scard)) return;
+	if (disable_modem) return;
+
+	if(sample_flag)
+		tx_sample_count += len;
+
+	if (progdefaults.viewXmtSignal &&
+		!(PERFORM_CPS_TEST || active_modem->XMLRPC_CPS_TEST))
+		trx_xmit_wfall_queue(samplerate, left, (size_t)len);
+
+	if (withnoise && progdefaults.noise) add_noise(left, len);
+
+	double mult = pow(10, progdefaults.txlevel / 20.0);
+	if (mult > 0.99) mult = 0.99;
+
+	for (int i = 0; i < len; i++) {
+		if (right[i] < -0.99) right[i] = -0.99;
+		if (right[i] >  0.99) right[i] = 0.99;
+		left[i] *= mult;
+		if (left[i] < -0.99) left[i] = -0.99;
+		if (left[i] >  0.99) left[i] = 0.99;
+	}
+	try {
+		unsigned n = 4;
+		while (scard->Write_stereo(left, right, len) == 0 && --n);
+		if (n == 0)
+			throw SndException(-99, "Sound write failed");
+	}
+	catch (const SndException& e) {
+		if(e.error() < 0) {
+ 			LOG_ERROR("%s", e.what());
+ 			throw;
+		}
+		return;
+	}
+
+}
+
+//------------------------------------------------------------------------------
+// modulate video signal
+//------------------------------------------------------------------------------
+void modem::ModulateVideoStereo(double *left, double *right, int len, bool sample_flag)
 {
 	if (unlikely(!scard)) return;
 
@@ -515,10 +570,48 @@ void modem::ModulateStereo(double *left, double *right, int len, bool sample_fla
 		}
 		return;
 	}
-
 }
 
+void modem::ModulateVideo(double *buffer, int len)
+{
+	if (unlikely(!scard)) return;
 
+	tx_sample_count += len;
+
+	if (progdefaults.PTTrightchannel) {
+		for (int i = 0; i < len; i++)
+			PTTchannel[i] = PTTnco();
+			ModulateVideoStereo( buffer, PTTchannel, len, false);
+		return;
+	}
+
+	if (progdefaults.viewXmtSignal &&
+		!(PERFORM_CPS_TEST || active_modem->XMLRPC_CPS_TEST))
+		trx_xmit_wfall_queue(samplerate, buffer, (size_t)len);
+
+	double mult = 0.99 * pow(10, progdefaults.txlevel / 20.0);
+	for (int i = 0; i < len; i++) {
+		buffer[i] *= mult;
+		if (buffer[i] < -1.0) buffer[i] = -1.0;
+		if (buffer[i] >  1.0) buffer[i] = 1.0;
+	}
+
+	try {
+		unsigned n = 4;
+		while (scard->Write(buffer, len) == 0 && --n);
+		if (n == 0)
+			throw SndException(-99, "Sound write failed");
+	}
+	catch (const SndException& e) {
+		if(e.error() < 0) {
+ 			LOG_ERROR("%s", e.what());
+ 			throw;
+		}
+		return;
+	}
+}
+
+//------------------------------------------------------------------------------
 void modem::videoText()
 {
 	if (trx_state == STATE_TUNE)
@@ -737,7 +830,7 @@ void modem::wfid_make_tones(int numchars)
 {
 	double f, flo, fhi;
 	int vwidth = (numchars*NUMCOLS + (numchars-1)*CHARSPACE - 1);
-	f = frequency + TONESPACING * vwidth/2.0;
+	f = tx_frequency + TONESPACING * vwidth/2.0;
 	fhi = f + TONESPACING;
 	flo = fhi - (vwidth + 2) * TONESPACING;
 	for (int i = 1; i <= NUMCOLS * numchars; i++) {
@@ -771,7 +864,7 @@ void modem::wfid_send(int numchars)
 		vidfilt.Irun( val, val );
 		wfid_outbuf[i] = val;
 	}
-	ModulateXmtr(wfid_outbuf, IDSYMLEN);
+	ModulateVideo(wfid_outbuf, IDSYMLEN);
 }
 
 void modem::wfid_sendchars(string s)
@@ -874,6 +967,8 @@ void modem::wfid_text(const string& s)
 
 	put_status(video.c_str());
 
+	disable_modem = true;
+
 	int numlines = 0;
 	string tosend;
 	while (numlines < len) numlines += vidwidth;
@@ -891,6 +986,7 @@ void modem::wfid_text(const string& s)
 	wfid_send(vidwidth);
 
 	put_status("");
+	disable_modem = false;
 }
 
 double	modem::wfid_outbuf[MAXIDSYMLEN];
