@@ -253,6 +253,9 @@ inline void WFdisp::makeMarker_(int width, const RGB* color, int freq, const RGB
 	if (marker_mode >= MODE_MT63_500S && marker_mode <= MODE_MT63_2000L)
 			bw_upper = (int)(width * 31 / 32);
 
+	if (marker_mode == MODE_FSQ)
+			bw_upper = (int)(width * 32 / 33);
+
 	if (bw_lower + static_cast<int>(freq+0.5) < 0)
 		bw_lower -= bw_lower + static_cast<int>(freq+0.5);
 
@@ -330,6 +333,7 @@ void WFdisp::makeMarker()
 	int bw_hi = marker_width;
 	if (mode >= MODE_MT63_500S && mode <= MODE_MT63_2000L)
 		bw_hi = bw_hi * 31 / 32;
+	if (mode == MODE_FSQ) bw_hi = bw_hi * 32 / 33;
 
 	for (int y = 0; y < WFMARKER - 2; y++) {
 		int incr = y * scale_width;
@@ -556,6 +560,7 @@ void WFdisp::processFFT() {
 					 IMAGE_WIDTH * sizeof(short int));
 		}
 		redraw();
+		Fl::flush();
 
 		dispcnt = 1.0 * WFBLOCKSIZE / SC_SMPLRATE; // FAST
 		if (wfspeed == NORMAL) dispcnt *= NORMAL;
@@ -602,6 +607,8 @@ void WFdisp::redrawCursor()
 //	cursormoved = true;
 }
 
+extern state_t trx_state;
+
 void WFdisp::sig_data( double *sig, int len, int sr )
 {
 	if (wfspeed == PAUSE)
@@ -879,6 +886,9 @@ case Step: for (int row = 0; row < image_height; row++) { \
 		trx_mode mode = active_modem->get_mode();
 		if (mode >= MODE_MT63_500S && mode <= MODE_MT63_2000L)
 			bw_hi = bw_hi * 31 / 32;
+		if (mode == MODE_FSQ) {
+			bw_hi = bw_lo = 69 * bandwidth / 100;
+		}
 		RGBI  *pos1 = fft_img + (carrierfreq - offset - bw_lo) / step;
 		RGBI  *pos2 = fft_img + (carrierfreq - offset + bw_hi) / step;
 		if (unlikely(pos2 == fft_img + disp_width))
@@ -945,6 +955,7 @@ void WFdisp::drawcolorWF() {
 		int bw_hi = bandwidth / 2;
 		if (mode >= MODE_MT63_500S && mode <= MODE_MT63_2000L)
 			bw_hi = bw_hi * 31 / 32;
+		if (mode == MODE_FSQ) bw_hi = bw_hi * 32 / 33;
 		RGBI  *pos0 = (fft_img + cursorpos);
 		RGBI  *pos1 = (fft_img + cursorpos - bw_lo/step);
 		RGBI  *pos2 = (fft_img + cursorpos + bw_hi/step);
@@ -1025,6 +1036,7 @@ void WFdisp::drawspectrum() {
 		int bw_hi = bandwidth / 2;
 		if (mode >= MODE_MT63_500S && mode <= MODE_MT63_2000L)
 			bw_hi = bw_hi * 31 / 32;
+		if (mode == MODE_FSQ) bw_hi = bw_hi * 32 / 33;
 		uchar  *pos0 = pixmap + cursorpos;
 		uchar  *pos1 = (pixmap + cursorpos - bw_lo/step);
 		uchar  *pos2 = (pixmap + cursorpos + bw_hi/step);
@@ -1221,8 +1233,7 @@ void xmtrcv_cb(Fl_Widget *w, void *vi)
 	FL_UNLOCK_D();
 	if (!(active_modem->get_cap() & modem::CAP_TX)) {
 		b->value(0);
-		restoreFocus();
-		return;
+		restoreFocus();		return;
 	}
 	if (v == 1) {
 		stopMacroTimer();
@@ -1770,7 +1781,7 @@ int waterfall::handle(int event)
 	// as above; handle wheel events for the macro bar
 	extern void altmacro_cb(Fl_Widget *w, void *v);
 	if (progdefaults.macro_wheel) {
-		if (progdefaults.mbar_scheme > 2) {
+		if (progdefaults.mbar_scheme > MACRO_SINGLE_BAR_MAX) {
 			if (Fl::event_inside(macroFrame2)) {
 				altmacro_cb(btnAltMacros2, reinterpret_cast<void *>(d));
 				return 1;
