@@ -66,6 +66,7 @@
 #include "status.h"
 #include "gettext.h"
 #include "arq_io.h"
+#include "fl_digi.h"
 
 #include "debug.h"
 
@@ -337,7 +338,7 @@ void FTextRX::add(unsigned int c, int attr)
 	}
 
 // test for bottom of text visibility
-	if (// !mFastDisplay && 
+	if (// !mFastDisplay &&
 		(mVScrollBar->value() >= mNBufferLines - mNVisibleLines + mVScrollBar->linesize() - 1))
 		show_insert_position();
 }
@@ -402,6 +403,7 @@ int FTextRX::handle_clickable(int x, int y)
 	switch (style - FTEXT_DEF) {
 	case QSY:
 		handle_qsy(start, end);
+		return 1;
 		break;
 	// ...
 	default:
@@ -437,7 +439,7 @@ int FTextRX::handle_qso_data(int start, int end)
 		return 0;
 	char* p = s;
 
-	Fl_Input* target = 0;
+	Fl_Input2* target = 0;
 
 	if (QsoInfoFrame1B->visible()) {
 		if (call.match(s)) { // point p to substring
@@ -445,11 +447,12 @@ int FTextRX::handle_qso_data(int start, int end)
 			p = s + offsets.rm_so;
 			*(s + offsets.rm_eo) = '\0';
 			inpCall->value(p);
-			inpCall->do_callback();
+			log_callback(inpCall);
 		} else {
 			inpXchgIn->position(inpXchgIn->size());
 			if (inpXchgIn->size()) inpXchgIn->insert(" ", 1);
 			inpXchgIn->insert(s);
+			log_callback(inpXchgIn);
 		}
 	} else {
 		if (rst.match(s))
@@ -468,15 +471,14 @@ int FTextRX::handle_qso_data(int start, int end)
 			target = *inpName->value() ? inpQth : inpName;
 		if (target) {
 			target->value(p);
-			target->do_callback();
+			log_callback(target);
 			free(s);
-			restoreFocus(NULL);
+			restoreFocus(91);
 			return 1;
 		}
 	}
 	free(s);
 	return 0;
-//	restoreFocus(NULL);
 }
 
 void FTextRX::handle_context_menu(void)
@@ -550,7 +552,7 @@ void FTextRX::handle_context_menu(void)
 ///
 void FTextRX::menu_cb(size_t item)
 {
-	Fl_Input* input = 0;
+	Fl_Input2* input = 0;
 	switch (item) {
 	case RX_MENU_QRZ_THIS:
 		menu_cb(RX_MENU_CALL);
@@ -622,7 +624,7 @@ void FTextRX::menu_cb(size_t item)
 		break;
 	}
 
-	restoreFocus(NULL);
+	restoreFocus(92);
 
 	if (!input)
 		return;
@@ -638,7 +640,7 @@ void FTextRX::menu_cb(size_t item)
 	}
 	else
 		input->value(s);
-	input->do_callback();
+	log_callback(input);
 	free(s);
 }
 
@@ -663,7 +665,7 @@ const char* FTextRX::dxcc_lookup_call(int x, int y)
 		const vector<regmatch_t>& v = loc.suboff();
 		s += v[0].rm_so;
 		*(s + v[0].rm_eo) = '\0';
-		if (locator2longlat(&lon2, &lat2, s) != RIG_OK)
+		if (QRB::locator2longlat(&lon2, &lat2, s) != QRB::QRB_OK)
 			goto ret;
 		e = 0; qsl = 0; qso = 0;
 	}
@@ -673,7 +675,7 @@ const char* FTextRX::dxcc_lookup_call(int x, int y)
 		qso = SearchLog(s);
 	}
 
-	if (qso && locator2longlat(&lon2, &lat2, qso->getField(GRIDSQUARE)) != RIG_OK)
+	if (qso && QRB::locator2longlat(&lon2, &lat2, qso->getField(GRIDSQUARE)) != QRB::QRB_OK)
 		lon2 = lat2 = 360.0;
 
 	if (e) {
@@ -687,11 +689,21 @@ const char* FTextRX::dxcc_lookup_call(int x, int y)
 		     << ") CQ-" << e->cq_zone << " ITU-" << e->itu_zone << '\n';
 	}
 
-	if (locator2longlat(&lon1, &lat1, progdefaults.myLocator.c_str()) == RIG_OK &&
-	    qrb(lon1, lat1, lon2, lat2, &distance, &azimuth) == RIG_OK) {
-		stip << "QTE " << fixed << setprecision(0) << azimuth << '\260' << " ("
-		     << azimuth_long_path(azimuth) << '\260' << ")  QRB " << distance << "km ("
-		     << distance_long_path(distance) << "km)\n";
+	if (QRB::locator2longlat(&lon1, &lat1, progdefaults.myLocator.c_str()) == QRB::QRB_OK &&
+	    QRB::qrb(lon1, lat1, lon2, lat2, &distance, &azimuth) == QRB::QRB_OK) {
+			if (progdefaults.us_units) {
+				stip << "QTE " << fixed << setprecision(0) << azimuth << '\260' << " ("
+					<< QRB::azimuth_long_path(azimuth) << '\260' << ")  QRB " 
+					<< distance * 0.62168188 << "mi"<< " (" <<
+					QRB::distance_long_path(distance) * 0.62168188 << 
+					"mi)\n";
+			}
+			else {
+				stip << "QTE " << fixed << setprecision(0) << azimuth << '\260' << " ("
+					<< QRB::azimuth_long_path(azimuth) << '\260' << ")  QRB "
+					<< distance << "km(" <<
+					QRB::distance_long_path(distance) << "km)\n";
+			}
 	}
 
 	if (qso) {
@@ -797,6 +809,12 @@ int FTextTX::handle(int event)
 
 	switch (event) {
 	case FL_KEYBOARD:
+		if (active_modem->get_mode() == MODE_FSQ) {
+			if (Fl::event_key() == FL_Enter || Fl::event_key() == FL_KP_Enter) {
+				fsq_transmit(active_modem);
+				return 1;
+			}
+		}
 		return handle_key(Fl::event_key()) ? 1 : FTextEdit::handle(event);
 	case FL_PUSH:
 		if (Fl::event_button() == FL_MIDDLE_MOUSE &&
@@ -957,15 +975,15 @@ int FTextTX::handle_key_shortcuts(int key)
 			default:
 				break;
 			}
-			
+
 			// Add text + space if length is > 0
 			if (etag.length())
 				add_text(etag + std::string(" "));
-			
+
 			return 1;
 		}
 		break;
-		
+
 	default:
 		break;
 	}
@@ -1029,7 +1047,7 @@ int FTextTX::handle_key(int key)
 		else if (!(Fl::event_state() & (FL_META | FL_ALT)))
 			break;
 		// fall through to (un)pause for M-r or A-r
-	
+
 	case FL_Pause:
 		if (trx_state != STATE_TX) {
 			start_tx();
@@ -1050,6 +1068,7 @@ int FTextTX::handle_key(int key)
 			active_modem->toggleWPM();
 		return 1;
 	case FL_Tab:
+		if (active_modem == fsq_modem) return 1;
 		// In non-CW modes: Tab and Ctrl-tab both pause until user moves the
 		// cursor to let some more text through. Another (ctrl-)tab goes back to
 		// the end of the buffer and resumes sending.
@@ -1075,12 +1094,14 @@ int FTextTX::handle_key(int key)
 	// Move cursor, or search up/down with the Meta/Alt modifiers
 	case FL_Left:
 		if (Fl::event_state() & (FL_META | FL_ALT)) {
+			if (active_modem == fsq_modem) return 1;
 			active_modem->searchDown();
 			return 1;
 		}
 		return 0;
 	case FL_Right:
 		if (Fl::event_state() & (FL_META | FL_ALT)) {
+			if (active_modem == fsq_modem) return 1;
 			active_modem->searchUp();
 			return 1;
 		}
@@ -1102,9 +1123,10 @@ int FTextTX::handle_key(int key)
 	case '3':
 	case '4':
 		if (Fl::event_state() & FL_ALT) {
+			if (active_modem == fsq_modem) return 1;
 			static char lbl[2] = "1";
 			altMacros = key - '1';
-			if (progdefaults.mbar_scheme > 2) {
+			if (progdefaults.mbar_scheme > MACRO_SINGLE_BAR_MAX) {
 				if (!altMacros) altMacros = 1;
 				for (int i = 0; i < NUMMACKEYS; i++) {
 					btnMacro[NUMMACKEYS + i]->label(
@@ -1135,9 +1157,9 @@ int FTextTX::handle_key(int key)
 		return 1;
 
 // insert a macro
-	if (key >= FL_F && key <= FL_F_Last)
+	if (key >= FL_F && key <= FL_F_Last) {
 		return handle_key_macro(key);
-
+	}
 // read ctl-ddd, where d is a digit, as ascii characters (in base 10)
 // and insert verbatim; e.g. ctl-001 inserts a <soh>
 	if (Fl::event_state() & FL_CTRL && (key >= FL_KP) && (key <= FL_KP + '9'))
@@ -1159,10 +1181,16 @@ int FTextTX::handle_key(int key)
 int FTextTX::handle_key_macro(int key)
 {
 	key -= FL_F + 1;
+
+	if (active_modem == fsq_modem) {
+		if (key == 0) fsq_repeat_last_heard();
+		if (key == 1) fsq_repeat_last_command();
+		return 1;
+	}
 	if (key > 11)
 		return 0;
 
-	if (progdefaults.mbar_scheme > 2) {
+	if (progdefaults.mbar_scheme > MACRO_SINGLE_BAR_MAX) {
 		if (Fl::event_state(FL_SHIFT))
 			key += altMacros * NUMMACKEYS;
 	} else {
